@@ -1,8 +1,9 @@
 import logging
-from typing import List
+from typing import Optional
 
+from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import \
+    ACIChunkLoadRpcABC
 from peek_plugin_base.PeekVortexUtil import peekServerName, peekClientName
-from peek_plugin_base.storage.DbConnection import DbSessionCreator
 from peek_plugin_docdb._private.PluginNames import docDbFilt
 from peek_plugin_docdb._private.storage.DocDbEncodedChunk import DocDbEncodedChunk
 from vortex.rpc.RPC import vortexRPC
@@ -10,9 +11,7 @@ from vortex.rpc.RPC import vortexRPC
 logger = logging.getLogger(__name__)
 
 
-class ClientChunkLoadRpc:
-    def __init__(self, dbSessionCreator: DbSessionCreator):
-        self._dbSessionCreator = dbSessionCreator
+class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
 
     def makeHandlers(self):
         """ Make Handlers
@@ -29,22 +28,10 @@ class ClientChunkLoadRpc:
     # -------------
     @vortexRPC(peekServerName, acceptOnlyFromVortex=peekClientName, timeoutSeconds=60,
                additionalFilt=docDbFilt, deferToThread=True)
-    def loadDocumentChunks(self, offset: int, count: int) -> List[DocDbEncodedChunk]:
+    def loadDocumentChunks(self, offset: int, count: int) -> Optional[bytes]:
         """ Update Page Loader Status
 
         Tell the server of the latest status of the loader
 
         """
-        session = self._dbSessionCreator()
-        try:
-            chunks = (session
-                      .query(DocDbEncodedChunk)
-                      .order_by(DocDbEncodedChunk.id)
-                      .offset(offset)
-                      .limit(count)
-                      .yield_per(count))
-
-            return list(chunks)
-
-        finally:
-            session.close()
+        return self.ckiInitialLoadChunksPayloadBlocking(offset, count, DocDbEncodedChunk)
